@@ -8,7 +8,7 @@ class Profile(AbstractUser, core.models.Log):
     nm_completo = models.CharField(max_length=200, null=True)
 
     tipo_codigo = models.CharField(null=True, max_length=200)
-    tipo_tipo = models.CharField(null=True, max_length=200, default='USR.PROFILE.TIPO')
+    tipo_tipo = models.CharField(null=True, max_length=200, default='USR.PROFILE.TIPO', related_name='usr_profile_tipo')
     tipo = CompositeForeignKey(core.models.Tipo, on_delete=models.SET_NULL, null=True, related_name='tipo', to_fields={
         "codigo": "tipo_codigo",
         "tipo": "tipo_tipo"
